@@ -43,11 +43,11 @@
 #define IMAGE_ALPHA_NORMAL		1.0
 #define IMAGE_ALPHA_HIGHLIGHT	0.65
 
-#define _DEBUG
+// #define _DEBUG
 #ifdef _DEBUG
-// redefine g_debug() to g_message()
+// redefine // g_debug() to g_message()
 // TODO: find out how to get debug logs from hildon-desktop
-#define g_debug g_message
+#define // g_debug g_message
 #define USER_AGENT_VERSION_STRING (debug version)
 #else
 #define USER_AGENT_VERSION_STRING (some version number)
@@ -132,8 +132,8 @@ fetch_current_state (CCCHHDoorIsDesktopWidget *self)
 	char buffer[MAX_HTTP_SIZE+1];
 	memset(buffer, 0, sizeof(buffer));
 
-	g_debug("ccchh-dooris-widget: fetch_current_state()");
-	g_debug("ccchh-dooris-widget: fetching state from URL: %s", self->url);
+	// g_debug("ccchh-dooris-widget: fetch_current_state()");
+	// g_debug("ccchh-dooris-widget: fetching state from URL: %s", self->url);
 
 // why bother? we check error on open
 /*
@@ -145,7 +145,7 @@ if (!gnome_vfs_uri_exists(uri_struct)) {
 gnome_vfs_uri_unref(uri_struct);
 */
 
-	g_debug("ccchh-dooris-widget: gnome_vfs_open()");
+	// g_debug("ccchh-dooris-widget: gnome_vfs_open()");
 	gvfs_errno = gnome_vfs_open(&gvfs_handle, self->url, GNOME_VFS_OPEN_READ);
 
 	if (gvfs_errno != GNOME_VFS_OK) {
@@ -153,7 +153,7 @@ gnome_vfs_uri_unref(uri_struct);
 		return DOORIS_FNORD;
 	}
 
-	g_debug("ccchh-dooris-widget: gnome_vfs_read()");
+	// g_debug("ccchh-dooris-widget: gnome_vfs_read()");
 	gvfs_errno = gnome_vfs_read(gvfs_handle, buffer, MAX_HTTP_SIZE, &bytes_read);
 
 	if (gvfs_errno != GNOME_VFS_OK) {
@@ -161,11 +161,11 @@ gnome_vfs_uri_unref(uri_struct);
 		return DOORIS_FNORD;
 	}
 
-	g_debug("ccchh-dooris-widget: read %lld bytes", bytes_read);
+	// g_debug("ccchh-dooris-widget: read %lld bytes", bytes_read);
 // rest of buffer already zeroed by memset()
 //	buffer[bytes_read] = '\0';
 
-	g_debug("ccchh-dooris-widget: gnome_vfs_close()");
+	// g_debug("ccchh-dooris-widget: gnome_vfs_close()");
 	gnome_vfs_close(gvfs_handle);
  
 	self->last_change_ts = 0L;
@@ -181,10 +181,10 @@ gnome_vfs_uri_unref(uri_struct);
 
 	if (!strcmp(line, "locked")) {
 		state = DOORIS_CLOSED;
-		g_debug("ccchh-dooris-widget: current state: closed");
+		// g_debug("ccchh-dooris-widget: current state: closed");
 	} else if (!strcmp(line, "unlocked")) {
 		state = DOORIS_OPEN;
-		g_debug("ccchh-dooris-widget: current state: open");
+		// g_debug("ccchh-dooris-widget: current state: open");
 	}
 	else {
 		g_warning("ccchh-dooris-widget: could not parse response");
@@ -199,7 +199,7 @@ gnome_vfs_uri_unref(uri_struct);
 		if (ts && !errno) {
 			self->last_report_ts = ts;
 		}
-		g_debug("ccchh-dooris-widget: last_report_ts: %lu, errno: %i\n", ts, errno);
+		// g_debug("ccchh-dooris-widget: last_report_ts: %lu, errno: %i\n", ts, errno);
 
 		// third line of body is last state change timestamp
 
@@ -209,7 +209,7 @@ gnome_vfs_uri_unref(uri_struct);
 			if (ts && !errno) {
 				self->last_change_ts = ts;
 			}
-			g_debug("ccchh-dooris-widget: last_change_ts: %lu, errno: %i\n", ts, errno);
+			// g_debug("ccchh-dooris-widget: last_change_ts: %lu, errno: %i\n", ts, errno);
 		}
 	}
 
@@ -224,7 +224,7 @@ stop_update_timer(CCCHHDoorIsDesktopWidget *self)
 {
 	// stop timer if it was running
 	if (self->timeout_handler) {
-		g_debug("ccchh-dooris-widget: stopping update timer");
+		// g_debug("ccchh-dooris-widget: stopping update timer");
 		g_source_remove (self->timeout_handler);
 		self->timeout_handler = 0;
 		return TRUE;
@@ -240,7 +240,7 @@ static inline gboolean
 start_update_timer(CCCHHDoorIsDesktopWidget *self)
 {
 	if (!self->timeout_handler) {
-		g_debug("ccchh-dooris-widget: starting update timer");
+		// g_debug("ccchh-dooris-widget: starting update timer");
 		if (self->update < UPDATE_INTERVAL_MIN) {
 			g_warning("ccchh-dooris-widget: self->update < UPDATE_INTERVAL_MIN, maybe a bug?");
 			self->update = UPDATE_INTERVAL_MIN;
@@ -269,7 +269,7 @@ install_connection_handler(CCCHHDoorIsDesktopWidget *self)
 			G_CALLBACK (ccchh_dooris_desktop_widget_connection_event), self);
 		/* Set automatic events */
 		g_object_set (self->connection, "automatic-connection-events", TRUE, NULL);
-		g_debug("ccchh-dooris-widget: connection monitoring enabled");
+		// g_debug("ccchh-dooris-widget: connection monitoring enabled");
 		return TRUE;
 	}
 
@@ -286,7 +286,7 @@ remove_connection_handler(CCCHHDoorIsDesktopWidget *self)
 		g_object_set (self->connection, "automatic-connection-events", FALSE, NULL);
 		g_signal_handler_disconnect (self->connection, self->connection_handler);
 		self->connection_handler = 0;
-		g_debug("ccchh-dooris-widget: connection monitoring disabled");
+		// g_debug("ccchh-dooris-widget: connection monitoring disabled");
 		return TRUE;
 	}
 
@@ -302,10 +302,10 @@ remove_connection_handler(CCCHHDoorIsDesktopWidget *self)
 static gboolean
 update (CCCHHDoorIsDesktopWidget *self)
 {
-	g_debug("ccchh-dooris-widget: update()");
+	// g_debug("ccchh-dooris-widget: update()");
 
 	if (!self->connected) {
-		g_debug("ccchh-dooris-widget: not connected, not fetching new state");
+		// g_debug("ccchh-dooris-widget: not connected, not fetching new state");
 		return FALSE;
 	}
 
@@ -313,7 +313,7 @@ update (CCCHHDoorIsDesktopWidget *self)
 	self->current_state = fetch_current_state(self);
 
 	if (self->current_state == self->last_state) {
-		g_debug("ccchh-dooris-widget: state unchanged");
+		// g_debug("ccchh-dooris-widget: state unchanged");
 		return FALSE;
 	}
 
@@ -327,15 +327,15 @@ update (CCCHHDoorIsDesktopWidget *self)
 	switch (self->current_state) {
 		case DOORIS_OPEN:
 			self->image_current = cairo_image_surface_create_from_png(IMAGE_DOORIS_OPEN);
-			g_debug("ccchh-dooris-widget: image_current set to open");
+			// g_debug("ccchh-dooris-widget: image_current set to open");
 			break;
 		case DOORIS_CLOSED:
 			self->image_current = cairo_image_surface_create_from_png(IMAGE_DOORIS_CLOSED);
-			g_debug("ccchh-dooris-widget: image_current set to closed");
+			// g_debug("ccchh-dooris-widget: image_current set to closed");
 			break;
 		default:
 			self->image_current = cairo_image_surface_create_from_png(IMAGE_DOORIS_FNORD);
-			g_debug("ccchh-dooris-widget: image_current set to fnord");
+			// g_debug("ccchh-dooris-widget: image_current set to fnord");
 			break;
 	}
 
@@ -344,7 +344,7 @@ update (CCCHHDoorIsDesktopWidget *self)
 	// state is valid and has changed since last known state
 	if (self->current_state != DOORIS_FNORD && self->current_state != self->last_known_state) {
 		self->last_known_state = self->current_state;
-		g_debug("ccchh-dooris-widget: state changed");
+		// g_debug("ccchh-dooris-widget: state changed");
 		return TRUE;
 	}
 
@@ -357,10 +357,10 @@ draw (CCCHHDoorIsDesktopWidget *self, cairo_t *cr)
 {
 //  GtkWidget *widget = GTK_WIDGET(self);
   
-	g_debug("ccchh-dooris-widget: draw()");
+	// g_debug("ccchh-dooris-widget: draw()");
 
 	if (!self->image_current) {
-		g_debug("ccchh-dooris-widget: draw() without image");
+		// g_debug("ccchh-dooris-widget: draw() without image");
 		self->image_current = cairo_image_surface_create_from_png(IMAGE_DOORIS_FNORD);
 	}
 
@@ -372,7 +372,7 @@ draw (CCCHHDoorIsDesktopWidget *self, cairo_t *cr)
 
 	// if not connected, overlay icon with "disconnected" image
 	if (!self->connected) {
-		g_debug("ccchh-dooris-widget: not connected, overlay image");
+		// g_debug("ccchh-dooris-widget: not connected, overlay image");
 		cairo_surface_t *image_overlay = cairo_image_surface_create_from_png(IMAGE_OVERLAY_DISCONNECTED);
 		cairo_set_source_surface(cr, image_overlay, 5, 5);
 		cairo_paint_with_alpha(cr, self->current_alpha);
@@ -389,7 +389,7 @@ show_status_banner (CCCHHDoorIsDesktopWidget *self)
 	time_t timenow, timediff;
 	gchar *text, *ts_text;
 
-	g_debug("ccchh-dooris-widget: show_status_banner()");
+	// g_debug("ccchh-dooris-widget: show_status_banner()");
 
 	time (&timenow);
 
@@ -443,7 +443,7 @@ show_status_banner (CCCHHDoorIsDesktopWidget *self)
 static void
 force_redraw (CCCHHDoorIsDesktopWidget *self)
 {
-	g_debug("ccchh-dooris-widget: force_redraw()");
+	// g_debug("ccchh-dooris-widget: force_redraw()");
 
 	/* Invalidate the drawing: */
 	GtkWidget *widget = GTK_WIDGET (self);
@@ -472,12 +472,18 @@ ccchh_dooris_desktop_widget_on_timeout (gpointer data)
 {
 	CCCHHDoorIsDesktopWidget *self = CCCHH_DOORIS_DESKTOP_WIDGET (data);
   
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_on_timeout()");
+	// g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_on_timeout()");
+
+	// stop event when offline
+	// connection event starts the timer again
+	if (!self->connected) {
+		return FALSE;
+	}
 
 // TODO: glib locking?
 // update() must be called only once at a time
 if (self->updating) {
-	g_debug("ccchh-dooris-widget: update lock set, not updating");
+	// g_debug("ccchh-dooris-widget: update lock set, not updating");
 	return TRUE;
 }
 self->updating = TRUE;
@@ -509,10 +515,10 @@ ccchh_dooris_desktop_widget_expose_event (GtkWidget *widget, GdkEventExpose *eve
 	cairo_t *cr  = gdk_cairo_create (widget->window);
 	CCCHHDoorIsDesktopWidget *self = CCCHH_DOORIS_DESKTOP_WIDGET (widget);
 
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_expose_event()");
+	// g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_expose_event()");
 
 	if (!self->image_current) {
-		g_debug("ccchh-dooris-widget: expose event without image");
+		// g_debug("ccchh-dooris-widget: expose event without image");
 		// no state yet, call update()
 		// flash banner if necessary and enabled
 		if (update(self) && self->notify) {
@@ -543,12 +549,12 @@ ccchh_dooris_desktop_widget_on_button_press_event (GtkWidget *widget,
 {
 	CCCHHDoorIsDesktopWidget *self = CCCHH_DOORIS_DESKTOP_WIDGET (widget);
 
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_on_button_press_event()");
+	// g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_on_button_press_event()");
  
 // TODO: glib locking?
 // update() must be called only once at a time
 if (self->updating) {
-	g_debug("ccchh-dooris-widget: update lock set, not updating");
+	// g_debug("ccchh-dooris-widget: update lock set, not updating");
 	return TRUE;
 }
 
@@ -565,7 +571,7 @@ self->updating = TRUE;
 	// TODO: this does not work immediately, the call to update()
 	// will still see !connected. maybe wait a bit or use a timer event?
 	if (!self->connected && self->force_connection) {
-		g_debug("ccchh-dooris-widget: not connected, requesting connection");
+		// g_debug("ccchh-dooris-widget: not connected, requesting connection");
 		/* Request connection and check for the result */
 		gboolean success = con_ic_connection_connect(self->connection,
 			CON_IC_CONNECT_FLAG_NONE);
@@ -614,7 +620,7 @@ ccchh_dooris_desktop_widget_connection_event(ConIcConnection *connection,
 {
 	CCCHHDoorIsDesktopWidget *self = CCCHH_DOORIS_DESKTOP_WIDGET (user_data);
 
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_connection_event()");
+	// g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_connection_event()");
 
 	// libconic signalled a connection state change
 
@@ -622,7 +628,7 @@ ccchh_dooris_desktop_widget_connection_event(ConIcConnection *connection,
 
 		// we are online now
 		self->connected = TRUE;
-		g_debug("ccchh-dooris-widget: new connection state: online");
+		// g_debug("ccchh-dooris-widget: new connection state: online");
 
 		// start timer
 		start_update_timer(self);
@@ -634,10 +640,13 @@ ccchh_dooris_desktop_widget_connection_event(ConIcConnection *connection,
 
 		// we are offline now
 		self->connected = FALSE;
-		g_debug("ccchh-dooris-widget: new connection state: offline");
+		// g_debug("ccchh-dooris-widget: new connection state: offline");
 
-		// stop timer
-		stop_update_timer(self);
+		// don't stop timer here
+		// it will deactivate itsef if !connected
+		// frequent stop/start would prevent it from firing
+//		// stop timer
+//		stop_update_timer(self);
 
 		// force redraw to add disconnection overlay
 		force_redraw(self);
@@ -655,12 +664,12 @@ ccchh_dooris_desktop_widget_on_settings_dialog_response (GtkDialog *dialog,
 	g_assert (self->settings_window);
 	g_assert (self->settings_window == GTK_WIDGET (dialog));
   
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_on_settings_dialog_response()");
+	// g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_on_settings_dialog_response()");
 
 	// only use new settings if user pressed the OK button
 	// TODO: add reset button to restore defaults
 	if (response_id == GTK_RESPONSE_ACCEPT) {
-		g_debug("ccchh-dooris-widget: response accept");
+		// g_debug("ccchh-dooris-widget: response accept");
 
 		// status URL
 		if (self->url) {
@@ -672,13 +681,13 @@ ccchh_dooris_desktop_widget_on_settings_dialog_response (GtkDialog *dialog,
 //		self->url = g_strdup(gtk_entry_get_text(GTK_ENTRY (self->url_entry)));
 		// try to build a valid URI from user input
 		self->url = gnome_vfs_make_uri_from_input(gtk_entry_get_text(GTK_ENTRY (self->url_entry)));
-		g_debug("ccchh-dooris-widget: new URL: %s\n", self->url);
+		// g_debug("ccchh-dooris-widget: new URL: %s\n", self->url);
 
 
 		// update interval
 		const gchar *choice = hildon_button_get_value(HILDON_BUTTON (self->update_picker));
 		self->update = CLAMP(g_ascii_strtod (choice, NULL), UPDATE_INTERVAL_MIN, UPDATE_INTERVAL_MAX);
-		g_debug("ccchh-dooris-widget: new update interval: %ld\n", (long)self->update);
+		// g_debug("ccchh-dooris-widget: new update interval: %ld\n", (long)self->update);
 
 		// if a timer was running, reset it
 		if (stop_update_timer(self)) {
@@ -688,9 +697,9 @@ ccchh_dooris_desktop_widget_on_settings_dialog_response (GtkDialog *dialog,
 		// banner notifications
 		self->notify = hildon_check_button_get_active(HILDON_CHECK_BUTTON(self->notify_button));
 		if (self->notify) {
-			g_debug("ccchh-dooris-widget: notification enabled");
+			// g_debug("ccchh-dooris-widget: notification enabled");
 		} else {
-			g_debug("ccchh-dooris-widget: notification disabled");
+			// g_debug("ccchh-dooris-widget: notification disabled");
 		}
 
 		// monitor internet connection state, only update if online
@@ -714,9 +723,9 @@ ccchh_dooris_desktop_widget_on_settings_dialog_response (GtkDialog *dialog,
 		// button forces internet connection
 		self->force_connection = hildon_check_button_get_active(HILDON_CHECK_BUTTON(self->connforce_button));
 		if (self->force_connection) {
-			g_debug("ccchh-dooris-widget: button forces connection");
+			// g_debug("ccchh-dooris-widget: button forces connection");
 		} else {
-			g_debug("ccchh-dooris-widget: button does not force connection");
+			// g_debug("ccchh-dooris-widget: button does not force connection");
 		}
 	}
 
@@ -749,7 +758,7 @@ ccchh_dooris_desktop_widget_on_show_settings (GtkWidget *widget G_GNUC_UNUSED,
 {
 	CCCHHDoorIsDesktopWidget *self = CCCHH_DOORIS_DESKTOP_WIDGET (widget);
  
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_on_show_settings()");
+	// g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_on_show_settings()");
 
 	// could this be called when the settings window is already open?
 	if (!self->settings_window) {
@@ -862,7 +871,7 @@ ccchh_dooris_desktop_widget_on_show_settings (GtkWidget *widget G_GNUC_UNUSED,
 static void
 ccchh_dooris_desktop_widget_realize (GtkWidget *widget)
 {
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_realize()");
+	// g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_realize()");
 
 	/* Use An RGBA colormap rather than RGB, 
 	 * so we can use transparency in our expose_event() implementation.
@@ -884,7 +893,7 @@ ccchh_dooris_desktop_widget_dispose (GObject *object)
 {
 	CCCHHDoorIsDesktopWidget *self = CCCHH_DOORIS_DESKTOP_WIDGET (object);
  
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_dispose()");
+	// g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_dispose()");
 
 	// remove settings window if it is still open
 	if (self->settings_window) {
@@ -903,7 +912,7 @@ ccchh_dooris_desktop_widget_finalize (GObject *object)
 {
 	CCCHHDoorIsDesktopWidget *self = CCCHH_DOORIS_DESKTOP_WIDGET (object);
 
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_finalize()");
+	// g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_finalize()");
  
 	stop_update_timer(self);
   
@@ -936,7 +945,7 @@ ccchh_dooris_desktop_widget_class_init (CCCHHDoorIsDesktopWidgetClass *klass)
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_class_init()");
+	// g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_class_init()");
 
 	object_class->dispose = ccchh_dooris_desktop_widget_dispose;
 	object_class->finalize = ccchh_dooris_desktop_widget_finalize;
@@ -949,14 +958,14 @@ ccchh_dooris_desktop_widget_class_init (CCCHHDoorIsDesktopWidgetClass *klass)
 static void
 ccchh_dooris_desktop_widget_class_finalize (CCCHHDoorIsDesktopWidgetClass *klass G_GNUC_UNUSED)
 {
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_class_finalize()");
+	// g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_class_finalize()");
 }
 
 
 static void
 ccchh_dooris_desktop_widget_init (CCCHHDoorIsDesktopWidget *self)
 {
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_init()");
+	// g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_init()");
 
 	// initialize GnomeVFS library
 	if (!gnome_vfs_init()) {
@@ -1028,7 +1037,7 @@ ccchh_dooris_desktop_widget_init (CCCHHDoorIsDesktopWidget *self)
 		self->connected = TRUE;
 		start_update_timer(self);
 	}
-	g_debug("ccchh-dooris-widget: initial URL: %s\n", self->url);
+	// g_debug("ccchh-dooris-widget: initial URL: %s\n", self->url);
 }
 
 
@@ -1036,6 +1045,6 @@ ccchh_dooris_desktop_widget_init (CCCHHDoorIsDesktopWidget *self)
 CCCHHDoorIsDesktopWidget*
 ccchh_dooris_desktop_widget_new (void)
 {
-	g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_new()");
+	// g_debug("ccchh-dooris-widget: ccchh_dooris_desktop_widget_new()");
 	return g_object_new (TYPE_CCCHH_DOORIS_DESKTOP_WIDGET, NULL);
 }
